// Copyright 2020 Tero Karvinen http://TeroKarvinen.com

package main

import (
	"flag"
	"fmt"
	"time"
)

func main() {
	/* Parse command line arguments */
	var n int
	flag.IntVar(&n, "n", 30, "days to print")

	var lang string
	flag.StringVar(&lang, "lang", "en", "language for weekdays (fi or en)")

	var weekHeadings bool
	flag.BoolVar(&weekHeadings, "week-headings", true, "print headings for each week")
	
	flag.Parse()

	weekdays := []string{"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"}
	if lang == "fi" {
		weekdays = []string{"su", "ma", "ti", "ke", "to", "pe", "la"}
	}

	/* Print dates */
	day := time.Now()
	for i := 0; i<n; i++ {
		_, w := day.ISOWeek()

		// Print week heading
		if weekHeadings && day.Weekday() == time.Monday {
			fmt.Printf("%v w%02d  \n", day.Format("2006-01-02"), w)
		}

		// Print date
		weekday := weekdays[day.Weekday()]
		fmt.Printf("%v w%02d %s  \n", day.Format("2006-01-02"), w, weekday)
		day = day.Add(time.Hour*24)
	}
}
